@@ -65,7 +65,8 @@ sub mk_app {
     $self->{startperl} = $Config{startperl};
     $self->{scriptgen} = $Catalyst::CATALYST_SCRIPT_GEN;
     $self->{author}    = $self->{author} = $ENV{'AUTHOR'}
-      || eval { @{ [ getpwuid($<) ] }[6] } || 'A clever guy';
+      || eval { @{ [ getpwuid($<) ] }[6] }
+      || 'Catalyst developer';
     $self->_mk_dirs;
     $self->_mk_appclass;
     $self->_mk_build;
@@ -74,7 +75,7 @@ sub mk_app {
     $self->_mk_changes;
     $self->_mk_apptest;
     $self->_mk_cgi;
-    $self->_mk_fcgi;
+    $self->_mk_fastcgi;
     $self->_mk_server;
     $self->_mk_test;
     $self->_mk_create;
@@ -93,7 +94,8 @@ sub mk_component {
     my $app  = shift;
     $self->{app} = $app;
     $self->{author} = $self->{author} = $ENV{'AUTHOR'}
-      || eval { @{ [ getpwuid($<) ] }[6] } || 'A clever guy';
+      || eval { @{ [ getpwuid($<) ] }[6] }
+      || 'A clever guy';
     $self->{base} = File::Spec->catdir( $FindBin::Bin, '..' );
     unless ( $_[0] =~ /^model|m|view|v|controller|c\$/i ) {
         my $helper = shift;
@@ -108,7 +110,7 @@ sub mk_component {
     else {
         my $type   = shift;
         my $name   = shift || "Missing name for model/view/controller";
-        my $helper = shift ;
+        my $helper = shift;
         my @args   = @_;
         return 0 if $name =~ /[^\w\:]/;
         $type = 'M' if $type =~ /model|m/i;
@@ -307,40 +309,40 @@ sub _mk_apptest {
 }
 
 sub _mk_cgi {
-    my $self   = shift;
-    my $script = $self->{script};
+    my $self      = shift;
+    my $script    = $self->{script};
     my $appprefix = $self->{appprefix};
     $self->render_file( 'cgi', "$script\/$appprefix\_cgi.pl" );
     chmod 0700, "$script/$appprefix\_cgi.pl";
 }
 
-sub _mk_fcgi {
-    my $self   = shift;
-    my $script = $self->{script};
+sub _mk_fastcgi {
+    my $self      = shift;
+    my $script    = $self->{script};
     my $appprefix = $self->{appprefix};
-    $self->render_file( 'fcgi', "$script\/$appprefix\_fcgi.pl" );
-    chmod 0700, "$script/$appprefix\_fcgi.pl";
+    $self->render_file( 'fastcgi', "$script\/$appprefix\_fastcgi.pl" );
+    chmod 0700, "$script/$appprefix\_fastcgi.pl";
 }
 
 sub _mk_server {
-    my $self   = shift;
-    my $script = $self->{script};
+    my $self      = shift;
+    my $script    = $self->{script};
     my $appprefix = $self->{appprefix};
     $self->render_file( 'server', "$script\/$appprefix\_server.pl" );
     chmod 0700, "$script/$appprefix\_server.pl";
 }
 
 sub _mk_test {
-    my $self   = shift;
-    my $script = $self->{script};
+    my $self      = shift;
+    my $script    = $self->{script};
     my $appprefix = $self->{appprefix};
     $self->render_file( 'test', "$script/$appprefix\_test.pl" );
     chmod 0700, "$script/$appprefix\_test.pl";
 }
 
 sub _mk_create {
-    my $self   = shift;
-    my $script = $self->{script};
+    my $self      = shift;
+    my $script    = $self->{script};
     my $appprefix = $self->{appprefix};
     $self->render_file( 'create', "$script\/$appprefix\_create.pl" );
     chmod 0700, "$script/$appprefix\_create.pl";
@@ -414,22 +416,32 @@ our $VERSION = '0.01';
 
 [% name %]->setup;
 
+=head1 NAME
+
+[% name %] - Catalyst based application
+
+=head1 SYNOPSIS
+
+    script/[% appprefix %]_server.pl
+
+=head1 DESCRIPTION
+
+Catalyst based application.
+
+=head1 METHODS
+
+=over 4
+
+=item default
+
+=cut
+
 sub default : Private {
     my ( $self, $c ) = @_;
     $c->res->output('Congratulations, [% name %] is on Catalyst!');
 }
 
-=head1 NAME
-
-[% name %] - A very nice application
-
-=head1 SYNOPSIS
-
-    Very simple to use
-
-=head1 DESCRIPTION
-
-Very nice application.
+=back
 
 =head1 AUTHOR
 
@@ -443,7 +455,6 @@ it under the same terms as perl itself.
 =cut
 
 1;
-
 __makefile__
     unless ( eval "use Module::Build::Compat 0.02; 1" ) {
         print "This module requires Module::Build to install itself.\n";
@@ -474,7 +485,6 @@ __makefile__
     Module::Build::Compat->run_build_pl( args => \@ARGV );
     require Module::Build;
     Module::Build::Compat->write_makefile( build_class => 'Module::Build' );
-
 __build__
 use strict;
 use Catalyst::Build;
@@ -489,22 +499,17 @@ my $build = Catalyst::Build->new(
     test_files         => [ glob('t/*.t'), glob('t/*/*.t') ]
 );
 $build->create_build_script;
-
 __readme__
 Run script/[% apprefix %]_server.pl to test the application.
-
 __changes__
 This file documents the revision history for Perl extension [% name %].
-
 0.01  [% time %]
         - initial revision, generated by Catalyst
-
 __apptest__
 use Test::More tests => 2;
 use_ok( Catalyst::Test, '[% name %]' );
 
 ok( request('/')->is_success );
-
 __podtest__
 use Test::More;
 
@@ -513,7 +518,6 @@ plan skip_all => 'Test::Pod 1.14 required' if $@;
 plan skip_all => 'set TEST_POD to enable this test' unless $ENV{TEST_POD};
 
 all_pod_files_ok();
-
 __podcoveragetest__
 use Test::More;
 
@@ -522,10 +526,9 @@ plan skip_all => 'Test::Pod::Coverage 1.04 required' if $@;
 plan skip_all => 'set TEST_POD to enable this test' unless $ENV{TEST_POD};
 
 all_pod_coverage_ok();
-
 __cgi__
 [% startperl %] -w
-BEGIN { $ENV{CATALYST_ENGINE} = 'CGI' }
+BEGIN { $ENV{CATALYST_ENGINE} ||= 'CGI' }
 
 use strict;
 use FindBin;
@@ -560,11 +563,10 @@ This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
-
-__fcgi__
+__fastcgi__
 [% startperl %] -w
 
-BEGIN { $ENV{CATALYST_ENGINE} = 'FCGI' }
+BEGIN { $ENV{CATALYST_ENGINE} ||= 'FastCGI' }
 
 use strict;
 use FindBin;
@@ -577,7 +579,7 @@ use [% name %];
 
 =head1 NAME
 
-fcgi - Catalyst FCGI
+fastcgi - Catalyst FastCGI
 
 =head1 SYNOPSIS
 
@@ -585,7 +587,7 @@ See L<Catalyst::Manual>
 
 =head1 DESCRIPTION
 
-Run a Catalyst application as fcgi.
+Run a Catalyst application as fastcgi.
 
 =head1 AUTHOR
 
@@ -599,12 +601,11 @@ This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
-
 __server__
 [% startperl %] -w
 
 BEGIN { 
-    $ENV{CATALYST_ENGINE} = 'HTTP';
+    $ENV{CATALYST_ENGINE} ||= 'HTTP';
     $ENV{CATALYST_SCRIPT_GEN} = [% scriptgen %];
 }  
 
@@ -658,11 +659,10 @@ This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
-
 __test__
 [% startperl %] -w
 
-BEGIN { $ENV{CATALYST_ENGINE} = 'Test' }
+BEGIN { $ENV{CATALYST_ENGINE} ||= 'Test' }
 
 use strict;
 use Getopt::Long;
@@ -716,7 +716,6 @@ This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
-
 __create__
 [% startperl %] -w
 
@@ -755,7 +754,6 @@ create.pl [options] model|view|controller name [helper] [options]
    create.pl model My::Model
    create.pl model SomeDB CDBI dbi:SQLite:/tmp/my.db
    create.pl model AnotherDB CDBI dbi:Pg:dbname=foo root 4321
-   create.pl Ajax
 
  See also:
    perldoc Catalyst::Manual
@@ -777,32 +775,40 @@ This library is free software. You can redistribute it and/or modify
 it under the same terms as perl itself.
 
 =cut
-
 __compclass__
 package [% class %];
 
 use strict;
 use base 'Catalyst::Base';
 
+=head1 NAME
+
+[% class %] - Catalyst component
+
+=head1 SYNOPSIS
+
+See L<[% app %]>
+
+=head1 DESCRIPTION
+
+Catalyst component.
 [% IF type == 'C' %]
+=head1 METHODS
+
+=over 4
+
+=item default
+
+=cut
+
 sub default : Private {
     my ( $self, $c ) = @_;
     $c->res->output('Congratulations, [% class %] is on Catalyst!');
 }
 
+=back
+
 [% END %]
-=head1 NAME
-
-[% class %] - A Component
-
-=head1 SYNOPSIS
-
-    Very simple to use
-
-=head1 DESCRIPTION
-
-Very nice component.
-
 =head1 AUTHOR
 
 [%author%]
@@ -815,7 +821,6 @@ it under the same terms as perl itself.
 =cut
 
 1;
-
 __comptest__
 [% IF type == 'C' %]
 use Test::More tests => 3;
